===============
 zope.security
===============

.. image:: https://img.shields.io/pypi/v/zope.security.svg
        :target: https://pypi.python.org/pypi/zope.security/
        :alt: Latest release

.. image:: https://img.shields.io/pypi/pyversions/zope.security.svg
        :target: https://pypi.org/project/zope.security/
        :alt: Supported Python versions

.. image:: https://travis-ci.org/zopefoundation/zope.security.svg?branch=master
        :target: https://travis-ci.org/zopefoundation/zope.security

.. image:: https://coveralls.io/repos/github/zopefoundation/zope.security/badge.svg?branch=master
        :target: https://coveralls.io/github/zopefoundation/zope.security?branch=master

.. image:: https://readthedocs.org/projects/zopesecurity/badge/?version=latest
        :target: https://zopesecurity.readthedocs.io/en/latest/
        :alt: Documentation Status


The Security framework provides a generic mechanism to implement security
policies on Python objects.

Documentation is available at https://zopesecurity.readthedocs.io/
